Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(439)

Unified Diff: chrome/browser/ui/ash/chrome_launcher_prefs.h

Issue 2378353002: [Merge-M54] Fix crash on item drag in shelf. (Closed)
Patch Set: Created 4 years, 3 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | chrome/browser/ui/ash/chrome_launcher_prefs.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/browser/ui/ash/chrome_launcher_prefs.h
diff --git a/chrome/browser/ui/ash/chrome_launcher_prefs.h b/chrome/browser/ui/ash/chrome_launcher_prefs.h
index 7f08d98574d7f8c998efaff21b05e59d40ccfcef..9f1f5e18cf96332f30f2316e07dbd888cb60f4eb 100644
--- a/chrome/browser/ui/ash/chrome_launcher_prefs.h
+++ b/chrome/browser/ui/ash/chrome_launcher_prefs.h
@@ -79,12 +79,12 @@ void RemovePinPosition(Profile* profile, const std::string& app_id);
// Updates information about pin position in sync model for the app |app_id|.
// |app_id_before| optionally specifies an app that exists right before the
// target app. |app_id_after| optionally specifies an app that exists right
// after the target app.
void SetPinPosition(Profile* profile,
const std::string& app_id,
const std::string& app_id_before,
- const std::string& app_id_after);
+ const std::vector<std::string>& app_ids_after);
// Used to propagate remote preferences to local during the first run.
class ChromeLauncherPrefsObserver
« no previous file with comments | « no previous file | chrome/browser/ui/ash/chrome_launcher_prefs.cc » ('j') | no next file with comments »
@@ -79,12 +79,12 @@ void RemovePinPosition(Profile* profile, const std::string& app_id);
// Updates information about pin position in sync model for the app |app_id|.
// |app_id_before| optionally specifies an app that exists right before the
-// target app. |app_id_after| optionally specifies an app that exists right
-// after the target app.
+// target app. |app_ids_after| optionally specifies sorted by position apps that
+// exist right after the target app.
void SetPinPosition(Profile* profile,
const std::string& app_id,

Powered by Google App Engine
This is Rietveld 408576698